<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author pau <pau@estuditic.com>
 * @author Marc Zulet <marczulet@gmail.com>
 * @author Joan <aseques@gmail.com>
 * @author David Surroca <davidsurrocaestrada@gmail.com>
 * @author Adolfo Jayme Barrientos <fito@libreoffice.org>
 * @author Carles Bellver <carles.bellver@cent.uji.es>
 * @author daniel <daniel@6temes.cat>
 * @author Eduard Díaz <edudiaz@scopia.es>
 * @author controlonline.net <controlonline.net@gmail.com>
 * @author Pauet <pauet@gmx.com>
 * @author Àngel Pérez Beroy <aperezberoy@gmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '«';
$lang['doublequoteclosing']    = '»';
$lang['singlequoteopening']    = '“';
$lang['singlequoteclosing']    = '”';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = 'Edita aquesta pàgina';
$lang['btn_source']            = 'Mostra el codi font';
$lang['btn_show']              = 'Mostra la pàgina';
$lang['btn_create']            = 'Crea aquesta pàgina';
$lang['btn_search']            = 'Cerca';
$lang['btn_save']              = 'Desa';
$lang['btn_preview']           = 'Previsualitza';
$lang['btn_top']               = 'Torna dalt';
$lang['btn_newer']             = '<< més recent';
$lang['btn_older']             = 'menys recent >>';
$lang['btn_revs']              = 'Revisions anteriors';
$lang['btn_recent']            = 'Canvis recents';
$lang['btn_upload']            = 'Penja';
$lang['btn_cancel']            = 'Cancel·la';
$lang['btn_index']             = 'Mapa del lloc';
$lang['btn_secedit']           = 'Edita';
$lang['btn_login']             = 'Entra';
$lang['btn_logout']            = 'Surt';
$lang['btn_admin']             = 'Admin';
$lang['btn_update']            = 'Actualitza';
$lang['btn_delete']            = 'Suprimeix';
$lang['btn_back']              = 'Enrere';
$lang['btn_backlink']          = 'Què hi enllaça';
$lang['btn_subscribe']         = 'Subscripció a canvis d\'aquesta pàgina';
$lang['btn_profile']           = 'Actualització del perfil';
$lang['btn_reset']             = 'Reinicia';
$lang['btn_resendpwd']         = 'Estableix una nova contrasenya';
$lang['btn_draft']             = 'Edita esborrany';
$lang['btn_recover']           = 'Recupera esborrany';
$lang['btn_draftdel']          = 'Suprimeix esborrany';
$lang['btn_revert']            = 'Restaura';
$lang['btn_register']          = 'Registra\'m';
$lang['btn_apply']             = 'Aplica';
$lang['btn_media']             = 'Gestor multimèdia';
$lang['btn_deleteuser']        = 'Suprimeix el meu compte';
$lang['btn_img_backto']        = 'Torna a %s';
$lang['btn_mediaManager']      = 'Veure a multimèdia mànager ';
$lang['loggedinas']            = 'Heu entrat com:';
$lang['user']                  = 'Nom d’usuari';
$lang['pass']                  = 'Contrasenya';
$lang['newpass']               = 'Contrasenya nova';
$lang['oldpass']               = 'Confirmeu la contrasenya actual';
$lang['passchk']               = 'una altra vegada';
$lang['remember']              = 'Recorda’m';
$lang['fullname']              = 'Nom complet';
$lang['email']                 = 'Adreça electrònica';
$lang['profile']               = 'Perfil d’usuari';
$lang['badlogin']              = 'Nom d\'usuari o contrasenya incorrectes.';
$lang['badpassconfirm']        = 'Contrasenya incorrecta';
$lang['minoredit']             = 'Canvis menors';
$lang['draftdate']             = 'L\'esborrany s\'ha desat automàticament';
$lang['nosecedit']             = 'Mentrestant la pàgina ha estat modificada. La informació de seccions estava obsoleta i ha calgut carregar la pàgina sencera.';
$lang['searchcreatepage']      = 'Si no heu trobat el que cercàveu, podeu crear o editar la pàgina %s, el nom de la qual deriva de la vostra consulta.';
$lang['search_fullresults']    = 'Resultats de text complet';
$lang['js']['search_toggle_tools'] = 'Commuta les eines de cerca';
$lang['js']['willexpire']      = 'El blocatge per a editar aquesta pàgina venç d\'aquí a un minut.\nUtilitzeu la visualització prèvia per reiniciar el rellotge i evitar conflictes.';
$lang['js']['notsavedyet']     = 'Heu fet canvis que es perdran si no els deseu.
Voleu continuar?';
$lang['js']['searchmedia']     = 'Cerca fitxers';
$lang['js']['keepopen']        = 'Manté la finestra oberta';
$lang['js']['hidedetails']     = 'Oculta detalls';
$lang['js']['mediatitle']      = 'Propietats de l\'enllaç';
$lang['js']['mediadisplay']    = 'Tipus d\'enllaç';
$lang['js']['mediaalign']      = 'Alineació';
$lang['js']['mediasize']       = 'Mida de la imatge';
$lang['js']['mediatarget']     = 'Destí de l\'enllaç';
$lang['js']['mediaclose']      = 'Tanca';
$lang['js']['mediainsert']     = 'Inserta';
$lang['js']['mediadisplayimg'] = 'Mostra la imatge';
$lang['js']['mediadisplaylnk'] = 'Mostra només l\'enllaç';
$lang['js']['mediasmall']      = 'Versió petita';
$lang['js']['mediamedium']     = 'Versió mitjana';
$lang['js']['medialarge']      = 'Versió gran';
$lang['js']['mediaoriginal']   = 'Versió original';
$lang['js']['medialnk']        = 'Enllaç a la pàgina de detalls';
$lang['js']['mediadirect']     = 'Enllaç directe a l\'original';
$lang['js']['medianolnk']      = 'No hi ha enllaç';
$lang['js']['medianolink']     = 'No enllacis la imatge';
$lang['js']['medialeft']       = 'Alinea la imatge a l\'esquerra.';
$lang['js']['mediaright']      = 'Alinea la imatge a la dreta.';
$lang['js']['mediacenter']     = 'Alinea la imatge al mig.';
$lang['js']['medianoalign']    = 'No facis servir alineació.';
$lang['js']['nosmblinks']      = 'Els enllaços amb recursos compartits de Windows només funcionen amb el Microsoft Internet Explorer.
Si voleu podeu copiar i enganxar l\'enllaç.';
$lang['js']['linkwiz']         = 'Auxiliar d\'enllaços';
$lang['js']['linkto']          = 'Enllaça a:';
$lang['js']['del_confirm']     = 'Suprimiu aquesta entrada?';
$lang['js']['restore_confirm'] = 'Vols realment restaurar aquesta versió?';
$lang['js']['media_diff']      = 'Veure les diferències:';
$lang['js']['media_diff_both'] = 'Un al costat de l\'altre';
$lang['js']['media_diff_opacity'] = 'Resalta';
$lang['js']['media_diff_portions'] = 'Llisca';
$lang['js']['media_select']    = 'Escull els arxius';
$lang['js']['media_upload_btn'] = 'Pujar';
$lang['js']['media_done_btn']  = 'Fet';
$lang['js']['media_drop']      = 'Arrossega aquí els arxius a pujar';
$lang['js']['media_cancel']    = 'esborra';
$lang['js']['media_overwrt']   = 'Sobreescriu els arxius existents';
$lang['js']['data_insecure']   = 'ADVERTÈNCIA: Sembla que el vostre directori de dades no està degudament protegit. Si us plau, llegiu sobre <a href="https://www.dokuwiki.org/security#web_access_security">Seguretat de l\'Accés Web a DokuWiki</a>.';
$lang['search_exact_match']    = 'Coincidència exacta';
$lang['search_starts_with']    = 'Comença per';
$lang['search_ends_with']      = 'Termina per';
$lang['search_contains']       = 'Conté';
$lang['search_custom_match']   = 'Personalitzat';
$lang['search_any_ns']         = 'Qualsevol espai de noms';
$lang['search_any_time']       = 'Qualsevol temps';
$lang['search_past_7_days']    = 'La setmana passada';
$lang['search_past_month']     = 'El mes passat';
$lang['search_past_year']      = 'L’any passat';
$lang['search_sort_by_hits']   = 'Ordena per visites';
$lang['search_sort_by_mtime']  = 'Ordena per darrera modificació';
$lang['regmissing']            = 'Heu d\'omplir tots els camps.';
$lang['reguexists']            = 'Ja existeix un altre usuari amb aquest nom.';
$lang['regsuccess']            = 'S\'ha creat l\'usuari. La contrasenya s\'ha enviat per correu.';
$lang['regsuccess2']           = 'S\'ha creat l\'usuari.';
$lang['regfail']               = 'L\'usuari no pot ser creat';
$lang['regmailfail']           = 'Sembla que un error ha impedit enviar la contrasenya per correu. Contacteu amb l\'administrador.';
$lang['regbadmail']            = 'L\'adreça de correu que heu donat no sembla vàlida. Si creieu que això és un error, contacu amb l\'administrador.';
$lang['regbadpass']            = 'Les dues contrasenyes no són iguals. Torneu a intentar-ho.';
$lang['regpwmail']             = 'La vostra contrasenya per al Wiki';
$lang['reghere']               = 'Si no teniu un compte, aquí en podeu obtenir un';
$lang['profna']                = 'Aquest wiki no permet modificar el perfil';
$lang['profnochange']          = 'No heu introduït cap canvi.';
$lang['profnoempty']           = 'No es pot deixar en blanc el nom o l\'adreça de correu.';
$lang['profchanged']           = 'El perfil d\'usuari s\'ha actualitzat correctament.';
$lang['profnodelete']          = 'Aquesta wiki no permet esborrar usuaris';
$lang['profdeleteuser']        = 'Esborrar compte';
$lang['profdeleted']           = 'El vostre compte ha sigut esborrat d\'aquest compte';
$lang['profconfdelete']        = 'Vull esmorrar el meu compte d\'aquesta wiki. </br> Aquesta acció no pot desfer-se.';
$lang['profconfdeletemissing'] = 'Confirmació no acceptada';
$lang['proffail']              = 'Perfil d\'usuari no actialitzat';
$lang['pwdforget']             = 'Heu oblidat la contrasenya? Podeu obtenir-ne una de nova.';
$lang['resendna']              = 'Aquest wiki no permet tornar a enviar la contrasenya.';
$lang['resendpwd']             = 'Estableix una nova contrasenya per';
$lang['resendpwdmissing']      = 'Heu d\'emplenar tots els camps.';
$lang['resendpwdnouser']       = 'No s\'ha pogut trobar aquest usuari a la base de dades.';
$lang['resendpwdbadauth']      = 'Aquest codi d\'autenticació no és vàlid. Assegureu-vos d\'utilitzar l\'enllaç de confirmació complet.';
$lang['resendpwdconfirm']      = 'Se us ha enviat per correu electrònic un enllaç de confirmació.';
$lang['resendpwdsuccess']      = 'Se us ha enviat la nova contrasenya per correu electrònic.';
$lang['license']               = 'Excepte on es digui una altra cosa, el contingut d\'aquest wiki està subjecte a la llicència següent:';
$lang['licenseok']             = 'Nota. En editar aquesta pàgina esteu acceptant que el vostre contingut estigui subjecte a la llicència següent:';
$lang['searchmedia']           = 'Cerca pel nom de fitxer';
$lang['searchmedia_in']        = 'Cerca en: %s';
$lang['txt_upload']            = 'Trieu el fitxer que voleu penjar:';
$lang['txt_filename']          = 'Introduïu el nom wiki (opcional):';
$lang['txt_overwrt']           = 'Sobreescriu el fitxer actual';
$lang['maxuploadsize']         = 'Puja com a màxim %s per arxiu.';
$lang['allowedmime']           = 'Llista d\'extensions permeses';
$lang['lockedby']              = 'Actualment blocat per:';
$lang['lockexpire']            = 'Venciment del blocatge:';
$lang['rssfailed']             = 'S\'ha produït un error en recollir aquesta alimentació: ';
$lang['nothingfound']          = 'No s\'ha trobat res.';
$lang['mediaselect']           = 'Selecció de fitxers';
$lang['uploadsucc']            = 'S\'ha penjat el fitxer';
$lang['uploadfail']            = 'No es pot penjar el fitxer. Potser no teniu prou permisos?';
$lang['uploadwrong']           = 'No es pot penjar el fitxer. Aquesta extensió està prohibida.';
$lang['uploadexist']           = 'El fitxer ja existeix. No s\'ha penjat.';
$lang['uploadbadcontent']      = 'El contingut que heu penjat coincideix amb l\'extensió de fitxer %s.';
$lang['uploadspam']            = 'La càrrega ha estat blocada per la llista negra de brossa.';
$lang['uploadxss']             = 'La càrrega ha estat blocada perquè podria ser un contingut maligne.';
$lang['uploadsize']            = 'El fitxer que voleu penjar és massa gran (màxim %s)';
$lang['deletesucc']            = 'S\'ha suprimit el fitxer "%s".';
$lang['deletefail']            = 'No s\'ha pogut suprimir el fitxer "%s". Comproveu els permisos.';
$lang['mediainuse']            = 'No s\'ha pogut suprimir el fitxer "%s". Encara s\'està utilitzant.';
$lang['namespaces']            = 'Espais';
$lang['mediafiles']            = 'Fitxers disponibles en';
$lang['accessdenied']          = 'No teniu permís per a veure aquesta pàgina.';
$lang['mediausage']            = 'Utilitzeu la sintaxi següent per referir-vos a aquest enllaç:';
$lang['mediaview']             = 'Mostra el fitxer original';
$lang['mediaroot']             = 'arrel';
$lang['mediaupload']           = 'Pengeu aquí un fitxer dins de l\'espai actual. Per a crear un nou subespai, poseu-ne el nom davant del nom de fitxer i separeu-los amb el signe de dos punts.';
$lang['mediaextchange']        = 'S\'ha canviat l\'extensió del fitxer de .%s a .%s';
$lang['reference']             = 'Referències per a';
$lang['ref_inuse']             = 'El fitxer no es pot suprimir perquè l\'estan utilitzant les pàgines següents:';
$lang['ref_hidden']            = 'Algunes referències apareixen en pàgines per a les quals no teniu permís de lectura';
$lang['hits']                  = 'Resultats';
$lang['quickhits']             = 'Noms de pàgina coincidents';
$lang['toc']                   = 'Taula de continguts';
$lang['current']               = 'actual';
$lang['yours']                 = 'La vostra versió';
$lang['diff']                  = 'Mostra diferències amb la versió actual';
$lang['diff2']                 = 'Mostra diferències entre les revisions seleccionades';
$lang['difflink']              = 'Enllaç a la visualització de la comparació';
$lang['diff_type']             = 'Veieu les diferències:';
$lang['diff_inline']           = 'En línia';
$lang['diff_side']             = 'Un al costat de l\'altre';
$lang['diffprevrev']           = 'Revisió prèvia';
$lang['diffnextrev']           = 'Següent revisió';
$lang['difflastrev']           = 'Ultima revisió';
$lang['diffbothprevrev']       = 'Ambdós costats versió prèvia';
$lang['diffbothnextrev']       = 'Ambdós costats nova versio';
$lang['line']                  = 'Línia';
$lang['breadcrumb']            = 'Camí:';
$lang['youarehere']            = 'Sou aquí:';
$lang['lastmod']               = 'Darrera modificació:';
$lang['by']                    = 'per';
$lang['deleted']               = 'suprimit';
$lang['created']               = 'creat';
$lang['restored']              = 's\'ha restaurat una versió anterior %s';
$lang['external_edit']         = 'edició externa';
$lang['summary']               = 'Resum d\'edició';
$lang['unknowndate']           = 'Data desconeguda';
$lang['noflash']               = 'Per a visualitzar aquest contingut necessiteu el <a href="http://get.adobe.com/flashplayer">connector d\'Adobe Flash</a>.';
$lang['download']              = 'Baixa el fragment';
$lang['tools']                 = 'Eines';
$lang['user_tools']            = 'Eines de l\'usuari';
$lang['site_tools']            = 'Eines del lloc';
$lang['page_tools']            = 'Eines de la pàgina';
$lang['skip_to_content']       = 'salta al contingut';
$lang['sidebar']               = 'Barra lateral';
$lang['mail_newpage']          = 'pàgina afegida:';
$lang['mail_changed']          = 'pàgina modificada:';
$lang['mail_subscribe_list']   = 'pàgines canviades a l’espai de noms:';
$lang['mail_new_user']         = 'nou usuari:';
$lang['mail_upload']           = 'fitxer penjat:';
$lang['changes_type']          = 'Veure els canvis de';
$lang['pages_changes']         = 'Pàgines';
$lang['media_changes']         = 'Arxius gràfics';
$lang['both_changes']          = 'Pàgines i arxius gràfics';
$lang['qb_bold']               = 'Negreta';
$lang['qb_italic']             = 'Cursiva';
$lang['qb_underl']             = 'Subratllat';
$lang['qb_code']               = 'Codi';
$lang['qb_strike']             = 'Text barrat';
$lang['qb_h1']                 = 'Encapçalament nivell 1';
$lang['qb_h2']                 = 'Encapçalament nivell 2';
$lang['qb_h3']                 = 'Encapçalament nivell 3';
$lang['qb_h4']                 = 'Encapçalament nivell 4';
$lang['qb_h5']                 = 'Encapçalament nivell 5';
$lang['qb_h']                  = 'Encapçalament';
$lang['qb_hs']                 = 'Selcciona l\'encapçalament';
$lang['qb_hplus']              = 'Encapçalament més alt';
$lang['qb_hminus']             = 'Encapçalament més baix';
$lang['qb_hequal']             = 'Encapçalament del mateix nivell';
$lang['qb_link']               = 'Enllaç intern';
$lang['qb_extlink']            = 'Enllaç extern';
$lang['qb_hr']                 = 'Ratlla horitzontal';
$lang['qb_ol']                 = 'Element de llista numerada';
$lang['qb_ul']                 = 'Element de llista de pics';
$lang['qb_media']              = 'Afegeix imatges o altres fitxers';
$lang['qb_sig']                = 'Insereix signatura';
$lang['qb_smileys']            = 'Emoticones';
$lang['qb_chars']              = 'Caràcters especials';
$lang['upperns']               = 'salta a l’espai superior';
$lang['metaedit']              = 'Edita metadades';
$lang['metasaveerr']           = 'No s\'han pogut escriure les metadades';
$lang['metasaveok']            = 'S\'han desat les metadades';
$lang['img_title']             = 'Títol:';
$lang['img_caption']           = 'Peu d\'imatge:';
$lang['img_date']              = 'Data:';
$lang['img_fname']             = 'Nom de fitxer:';
$lang['img_fsize']             = 'Mida:';
$lang['img_artist']            = 'Fotògraf:';
$lang['img_copyr']             = 'Copyright:';
$lang['img_format']            = 'Format:';
$lang['img_camera']            = 'Càmera:';
$lang['img_keywords']          = 'Paraules clau:';
$lang['img_width']             = 'Ample:';
$lang['img_height']            = 'Alçada:';
$lang['subscr_subscribe_success'] = 'S\'ha afegit %s a la llista de subscripcions per %s';
$lang['subscr_subscribe_error'] = 'Hi ha hagut un error a l\'afegir %s a la llista per %s';
$lang['subscr_subscribe_noaddress'] = 'No hi ha cap adreça associada pel vostre nom d\'usuari, no podeu ser afegit a la llista de subscripcions';
$lang['subscr_unsubscribe_success'] = 'S\'ha esborrat %s de la llista de subscripcions per %s';
$lang['subscr_unsubscribe_error'] = 'Hi ha hagut un error a l\'esborrar %s de la llista de subscripcions per %s';
$lang['subscr_already_subscribed'] = '%s ja està subscrit a %s';
$lang['subscr_not_subscribed'] = '%s no està subscrit a %s';
$lang['subscr_m_not_subscribed'] = 'En aquests moments no esteu subscrit a l\'actual pàgina o espai';
$lang['subscr_m_new_header']   = 'Afegeix subcripció';
$lang['subscr_m_current_header'] = 'Subscripcions actuals';
$lang['subscr_m_unsubscribe']  = 'Donar-se de baixa';
$lang['subscr_m_subscribe']    = 'Donar-se d\'alta';
$lang['subscr_m_receive']      = 'Rebre';
$lang['subscr_style_every']    = 'Envia\'m un correu electrònic per a cada canvi';
$lang['subscr_style_digest']   = 'Envia\'m un correu electrònic amb un resum dels canvis per a cada pàgina (cada %.2f dies)';
$lang['subscr_style_list']     = 'llistat de pàgines canviades des de l\'últim correu electrònic  (cada %.2f dies)';
$lang['authtempfail']          = 'L\'autenticació d\'usuaris no està disponible temporalment. Si aquesta situació persisteix, si us plau informeu els administradors del wiki.';
$lang['i_chooselang']          = 'Trieu l\'idioma';
$lang['i_installer']           = 'Instal·lador de DokuWiki';
$lang['i_wikiname']            = 'Nom del wiki';
$lang['i_enableacl']           = 'Habilita ACL (recomanat)';
$lang['i_superuser']           = 'Superusuari';
$lang['i_problems']            = 'L\'instal·lador ha trobat alguns problemes, que s\'indiquen més avall. No podeu continuar fins que no els hàgiu solucionat.';
$lang['i_modified']            = 'Per raons de seguretat aquesta seqüència només funciona amb una instal·lació nova i no modificada de Dokuwiki. Hauríeu de tornar a baixar el paquet i/o descomprimir-lo o consultar les <a href="https://www.dokuwiki.org/install">instruccions d\'instal·lació de Dokuwiki</a> completes';
$lang['i_funcna']              = 'La funció PHP <code>%s</code> no està disponible. Potser el vostre proveïdor de serveis l\'ha inhabilitada per alguna raó';
$lang['i_disabled']            = 'El vostre proveïdor l\'ha desactivat.';
$lang['i_funcnmail']           = '<b>Nota:</b> La funció de correu PHP no està disponible. %s Si es manté no disponible, podeu instal·lar el <a href="https://www.dokuwiki.org/plugin:smtp">connector smtp</a>.';
$lang['i_phpver']              = 'La vostra versió de PHP <code>%s</code> és inferior a la requerida <code>%s</code>. Necessiteu actualitzar la vostra instal·lació de PHP.';
$lang['i_mbfuncoverload']      = 'mbstring.func_overload cal que sigui deshabilitada en php.ini perquè funcioni DokuWiki';
$lang['i_urandom']             = 'DokuWiki no pot crear números criptogràficament segurs per a les galetes. És possible que vulgueu comprovar la vostra configuració d\'open_basedir al php.ini per un accés correcte a <code>/dev/urandom</code>.';
$lang['i_permfail']            = 'DokuWiki no pot escriure <code>%s</code>. Heu d\'arreglar els permisos d\'aquest directori';
$lang['i_confexists']          = '<code>%s</code> ja existeix';
$lang['i_writeerr']            = 'No es pot crear <code>%s</code>. Comproveu els permisos del directori i/o del fitxer i creeu el fitxer manualment.';
$lang['i_badhash']             = 'dokuwiki.php no reconegut o modificat (hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - valor il·legal o buit';
$lang['i_success']             = 'La configuració s\'ha acabat amb èxit. Ara podeu suprimir el fitxer install.php. Aneu al <a href="doku.php?id=wiki:welcome">vostre nou DokuWiki</a>.';
$lang['i_failure']             = 'S\'han produït alguns errors en escriure els fitxers de configuració. Potser caldrà que els arregleu manualment abans d\'utilitzar el <a href="doku.php?id=wiki:welcome">vostre nou DokuWiki</a>.';
$lang['i_policy']              = 'Política ACL inicial';
$lang['i_pol0']                = 'Wiki obert (tothom pot llegir, escriure i penjar fitxers)';
$lang['i_pol1']                = 'Wiki públic (tothom pot llegir, els usuaris registrats poden escriure i penjar fitxers)';
$lang['i_pol2']                = 'Wiki tancat (només els usuaris registrats poden llegir, escriure i penjar fitxers)';
$lang['i_allowreg']            = 'Permet d\'autoinscripció d\'usuaris';
$lang['i_retry']               = 'Reintenta';
$lang['i_license']             = 'Escolliu el tipus de llicència que voleu fer servir per al vostre contingut:';
$lang['i_license_none']        = 'No mostrar cap informació sobre llicencies';
$lang['i_pop_field']           = 'Si us plau, ajuda\'ns a millorar la DokuWiki';
$lang['i_pop_label']           = 'Una vegada al mes, enviar anònimament dades als programadors de la DokuWiki';
$lang['recent_global']         = 'Esteu veient els canvis recents de l\'espai <strong>%s</strong>. També podeu veure els <a href="%s">canvis recents de tot el wiki</a>.';
$lang['years']                 = 'fa %d anys';
$lang['months']                = 'fa %d mesos';
$lang['weeks']                 = 'fa %d setmanes';
$lang['days']                  = 'fa %d dies';
$lang['hours']                 = 'fa %d hores';
$lang['minutes']               = 'fa %d minuts';
$lang['seconds']               = 'fa %d segons';
$lang['wordblock']             = 'El vostre canvi no s\'ha guardat perquè conté text blocat (spam)';
$lang['media_uploadtab']       = 'Puja';
$lang['media_searchtab']       = 'Busca';
$lang['media_file']            = 'Fitxer';
$lang['media_viewtab']         = 'Mostra';
$lang['media_edittab']         = 'Edita';
$lang['media_historytab']      = 'Històric';
$lang['media_list_thumbs']     = 'Miniatura';
$lang['media_list_rows']       = 'Files';
$lang['media_sort_name']       = 'Nom';
$lang['media_sort_date']       = 'Data';
$lang['media_namespaces']      = 'Escolliu l\'espai';
$lang['media_files']           = 'Arxius a %s';
$lang['media_upload']          = 'Puja a %s';
$lang['media_search']          = 'Busca a %s';
$lang['media_view']            = '%s';
$lang['media_viewold']         = '%s a %s';
$lang['media_edit']            = 'Edita %s';
$lang['media_history']         = 'Històric de %s';
$lang['media_meta_edited']     = 'metadata editada';
$lang['media_perm_read']       = 'No teniu permisos suficients per a llegir arxius.';
$lang['media_perm_upload']     = 'No teniu permisos suficients per a pujar arxius';
$lang['media_update']          = 'Puja la nova versió';
$lang['media_restore']         = 'Restaura aquesta versió';
$lang['media_acl_warning']     = 'Aquesta llista pot no estar completa per restriccions ACL i per llistes ocultes';
$lang['email_fail']            = 'Falta el correu PHP () o està desactivat. No s\'ha enviat el correu electrònic següent:';
$lang['currentns']             = 'Espai de noms actual';
$lang['searchresult']          = 'Resultats cerca';
$lang['plainhtml']             = 'HTML pla';
$lang['wikimarkup']            = 'Wiki Marcatge';
$lang['page_nonexist_rev']     = 'Pàgina no existeix a %s. Aixó es conseqüencia d\'haver-la creada a <a href="%s">%s</a>.';
$lang['unable_to_parse_date']  = 'Impossible de esbrinar el paràmetre "%s".';
$lang['email_signature_text']  = 'Aquest mail ha estat generat per DokuWiki a
@DOKUWIKIURL@';
$lang['log_file_too_large']    = 'Fitxer de log massa gran. Linies anteriors ignorades!';
